@@ -48,7 +48,7 @@ class EventsManager extends CGExtensions
 			$name = $this->Lang('friendlyname');
 		return $name;
 	}
-	function GetVersion() { return '0.1.6'; }
+	function GetVersion() { return '0.1.6.1'; }
 	function GetHelp() { return $this->Lang('help'); }
 	function GetAuthor() { return 'AireLibre'; }
 	function GetAuthorEmail() { return 'contact@airelibre.fr'; }
@@ -111,7 +111,7 @@ class EventsManager extends CGExtensions
 		$this->SetParameterType('show',CLEAN_STRING);
 		$this->SetParameterType('start_datetime', CLEAN_STRING);
 		$this->SetParameterType('end_datetime', CLEAN_STRING);
-		$this->SetParameterType('myevents', CLEAN_INT);
+		$this->SetParameterType('myevents', CLEAN_STRING);
 		
 		// Templates
 		$this->SetParameterType('summarytemplate', CLEAN_STRING);
